@@ -4,7 +4,7 @@ use 5.000000;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 ###############################################################################
 ### PRECOMPILED REGEX
@@ -314,9 +314,12 @@ sub state {
 	my ($arg) = @_;
 
 	if ( $arg ) {
-		unless ( $arg =~ m/\A(NEW|ESTABLISHED|RELATED|INVALID|UNTRACKED)\z/i ) {
-			__errstr($self, 'invalid connection tracking state: '.$arg);
-			return;
+		my @states = split(",",$arg);
+		for (@states) {
+			unless ( $_ =~ m/\A(NEW|ESTABLISHED|RELATED|INVALID|UNTRACKED)\z/i ) {
+				__errstr($self, 'invalid connection tracking state: '.$_);
+				return;
+			}
 		}
 		$self->{state} = $arg;
 	}
@@ -476,7 +479,7 @@ sub generate {
 	
 	# Source and Destination Addresses
 	if ( defined($self->{src}) ) {
-		if ( __is_valid_inet_host($self->{src}) or &is_valid_inet_cidr($self->{src}) ) {
+		if ( __is_valid_inet_host($self->{src}) or __is_valid_inet_cidr($self->{src}) ) {
 			$rule_criteria .= sprintf(' -s %s', $self->{src});
 		}
 		if ( __is_valid_inet_range($self->{src}) ) {
@@ -484,7 +487,7 @@ sub generate {
 		}
 	}
 	if ( defined($self->{dst}) ) {
-		if ( __is_valid_inet_host($self->{dst}) or &is_valid_inet_cidr($self->{dst}) ) {
+		if ( __is_valid_inet_host($self->{dst}) or __is_valid_inet_cidr($self->{dst}) ) {
 			$rule_criteria .= sprintf(' -d %s', $self->{dst});
 		}
 		if ( __is_valid_inet_range($self->{dst}) ) {
@@ -1115,6 +1118,10 @@ this file.
 
 =over 8
 
+=item 0.02
+
+Allow multiple states to be used (comma-delimed). Typo fixed in function call.
+
 =item 0.01
 
 Original version; created by h2xs 1.23
@@ -1131,7 +1138,7 @@ Phillip Smith, E<lt>fukawi2@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011 by Phillip Smith
+Copyright (C) 2011-2016 by Phillip Smith
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.14.2 or,
